You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@clerezza.apache.org by re...@apache.org on 2015/01/12 20:27:11 UTC

[2/4] clerezza git commit: Adapted to updated RDF Commons draft

http://git-wip-us.apache.org/repos/asf/clerezza/blob/9ae0a1bc/rdf.core/src/main/java/org/apache/clerezza/rdf/core/serializedform/Parser.java
----------------------------------------------------------------------
diff --git a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/serializedform/ParsingProvider.java b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/serializedform/ParsingProvider.java
index d2e1ee6..9f45c7a 100644
--- a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/serializedform/ParsingProvider.java
+++ b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/serializedform/ParsingProvider.java
@@ -20,11 +20,11 @@ package org.apache.clerezza.rdf.core.serializedform;
 
 import java.io.InputStream;
 
-import org.apache.commons.rdf.MGraph;
+import org.apache.commons.rdf.Graph;
 import org.apache.commons.rdf.Iri;
 
 /**
- * An instance of this class parses RDF-Graph from one or more serialization
+ * An instance of this class parses RDF-ImmutableGraph from one or more serialization
  * formats. The supported formats are indicated using the {@link SupportedFormat}
  * annotation.
  *
@@ -38,12 +38,12 @@ public interface ParsingProvider {
      * before a ';'-character in the <code>formatIdentifier</code> matches
      * a <code>SupportedFormat</code> annotation of the implementing class.
      *
-     * @param target the mutable graph to which the read triples shall be added
-     * @param serializedGraph the stream from which the serialized graph is read
+     * @param target the mutable ImmutableGraph to which the read triples shall be added
+     * @param serializedGraph the stream from which the serialized ImmutableGraph is read
      * @param formatIdentifier a String identifying the format
      * @param baseUri the baseUri for interpreting relative uris, may be null
      */
-    void parse(MGraph target, InputStream serializedGraph,
+    void parse(Graph target, InputStream serializedGraph,
             String formatIdentifier, Iri baseUri);
 
 }

http://git-wip-us.apache.org/repos/asf/clerezza/blob/9ae0a1bc/rdf.core/src/main/java/org/apache/clerezza/rdf/core/serializedform/Serializer.java
----------------------------------------------------------------------
diff --git a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/serializedform/Serializer.java b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/serializedform/Serializer.java
index 7fece9b..8624722 100644
--- a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/serializedform/Serializer.java
+++ b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/serializedform/Serializer.java
@@ -32,7 +32,7 @@ import java.util.Map;
 import java.util.ServiceLoader;
 import java.util.Set;
 
-import org.apache.commons.rdf.TripleCollection;
+import org.apache.commons.rdf.Graph;
 import org.osgi.service.cm.ConfigurationAdmin;
 import org.osgi.service.component.ComponentContext;
 import org.osgi.service.component.annotations.Activate;
@@ -48,7 +48,7 @@ import org.slf4j.LoggerFactory;
 
 /**
  * This singleton class provides a method <code>serialize</code> to transform a
- * {@link Graph} into serialized RDF forms.
+ * {@link ImmutableGraph} into serialized RDF forms.
  * 
  * Functionality is delegated to registered {@link SerializingProvider}s. Such
  * <code>SerializingProvider</code>s can be registered and unregistered, later
@@ -151,20 +151,20 @@ public class Serializer {
     }
 
     /**
-     * Serializes a Graph into an OutputStream. This delegates the
+     * Serializes a ImmutableGraph into an OutputStream. This delegates the
      * processing to the provider registered for the specified format, if
      * the formatIdentifier contains a ';'-character only the section before
      * that character is used for choosing the provider.
      * 
      * @param serializedGraph
-     *            an outputStream into which the Graph will be serialized
-     * @param tc  the <code>TripleCollection</code> to be serialized
+     *            an outputStream into which the ImmutableGraph will be serialized
+     * @param tc  the <code>Graph</code> to be serialized
      * @param formatIdentifier
      *            a string specifying the serialization format (usually the
      *            MIME-type)
      * @throws UnsupportedFormatException
      */
-    public void serialize(OutputStream serializedGraph, TripleCollection tc,
+    public void serialize(OutputStream serializedGraph, Graph tc,
             String formatIdentifier) throws UnsupportedFormatException {
         String deParameterizedIdentifier;
         int semicolonPos = formatIdentifier.indexOf(';');

http://git-wip-us.apache.org/repos/asf/clerezza/blob/9ae0a1bc/rdf.core/src/main/java/org/apache/clerezza/rdf/core/serializedform/SerializingProvider.java
----------------------------------------------------------------------
diff --git a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/QueryEngine.java b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/QueryEngine.java
index d861067..9bcdb70 100644
--- a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/QueryEngine.java
+++ b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/QueryEngine.java
@@ -18,7 +18,7 @@
  */
 package org.apache.clerezza.rdf.core.sparql;
 
-import org.apache.commons.rdf.TripleCollection;
+import org.apache.commons.rdf.Graph;
 import org.apache.clerezza.rdf.core.access.TcManager;
 import org.apache.clerezza.rdf.core.sparql.query.Query;
 
@@ -36,14 +36,14 @@ public interface QueryEngine {
 	 * @param tcManager
 	 *            where the query originates.
 	 * @param defaultGraph
-	 *            the default graph against which to execute the query if no
+	 *            the default ImmutableGraph against which to execute the query if no
 	 *            FROM clause is present
 	 * @param query
 	 *            Query object to be executed
-	 * @return the resulting ResultSet, Graph or Boolean value
+	 * @return the resulting ResultSet, ImmutableGraph or Boolean value
 	 */
     @Deprecated
-	public Object execute(TcManager tcManager, TripleCollection defaultGraph,
+	public Object execute(TcManager tcManager, Graph defaultGraph,
 			Query query);
 
 	/**
@@ -53,12 +53,12 @@ public interface QueryEngine {
 	 * @param tcManager
 	 *            where the query originates.
 	 * @param defaultGraph
-	 *            the default graph against which to execute the query if no
+	 *            the default ImmutableGraph against which to execute the query if no
 	 *            FROM clause is present
 	 * @param query
 	 *            string to be executed.
-	 * @return the resulting ResultSet, Graph or Boolean value
+	 * @return the resulting ResultSet, ImmutableGraph or Boolean value
 	 */
-	public Object execute(TcManager tcManager, TripleCollection defaultGraph,
+	public Object execute(TcManager tcManager, Graph defaultGraph,
 			String query);
 }

http://git-wip-us.apache.org/repos/asf/clerezza/blob/9ae0a1bc/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/ResultSet.java
----------------------------------------------------------------------
diff --git a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/ResultSet.java b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/ResultSet.java
index 7364bc0..1d2e377 100644
--- a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/ResultSet.java
+++ b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/ResultSet.java
@@ -26,7 +26,7 @@ import java.util.List;
  * as per section 12.1.6 of http://www.w3.org/TR/rdf-sparql-query/.
  *
  * Note that the scope of blank nodes is the reult set and not the
- * TripleCollection from where they originate.
+ * Graph from where they originate.
  *
  * @author rbn
  */

http://git-wip-us.apache.org/repos/asf/clerezza/blob/9ae0a1bc/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/AlternativeGraphPattern.java
----------------------------------------------------------------------
diff --git a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/AlternativeGraphPattern.java b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/AlternativeGraphPattern.java
index a35959c..1e1424d 100644
--- a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/AlternativeGraphPattern.java
+++ b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/AlternativeGraphPattern.java
@@ -21,7 +21,7 @@ package org.apache.clerezza.rdf.core.sparql.query;
 import java.util.List;
 
 /**
- * Defines alternative graph patterns.
+ * Defines alternative ImmutableGraph patterns.
  * @see <a href="http://www.w3.org/TR/rdf-sparql-query/#alternatives">
  * SPARQL Query Language: 7 Matching Alternatives</a>
  *

http://git-wip-us.apache.org/repos/asf/clerezza/blob/9ae0a1bc/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/BasicGraphPattern.java
----------------------------------------------------------------------
diff --git a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/BasicGraphPattern.java b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/BasicGraphPattern.java
index ea0ef2e..c3ea802 100644
--- a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/BasicGraphPattern.java
+++ b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/BasicGraphPattern.java
@@ -21,9 +21,9 @@ package org.apache.clerezza.rdf.core.sparql.query;
 import java.util.Set;
 
 /**
- * Defines a basic graph pattern.
+ * Defines a basic ImmutableGraph pattern.
  * @see <a href="http://www.w3.org/TR/rdf-sparql-query/#BasicGraphPatterns">
- * SPARQL Query Language: 5.1 Basic Graph Patterns</a>
+ * SPARQL Query Language: 5.1 Basic ImmutableGraph Patterns</a>
  *
  * @author hasan
  */

http://git-wip-us.apache.org/repos/asf/clerezza/blob/9ae0a1bc/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/DataSet.java
----------------------------------------------------------------------
diff --git a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/DataSet.java b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/DataSet.java
index b30fb2f..d4b95b6 100644
--- a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/DataSet.java
+++ b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/DataSet.java
@@ -31,7 +31,7 @@ public interface DataSet {
     /**
      * 
      * @return
-     *        an empty set if no default graph is specified,
+     *        an empty set if no default ImmutableGraph is specified,
      *        otherwise a set of their UriRefs
      */
     public Set<Iri> getDefaultGraphs();
@@ -39,7 +39,7 @@ public interface DataSet {
     /**
      *
      * @return
-     *        an empty set if no named graph is specified,
+     *        an empty set if no named ImmutableGraph is specified,
      *        otherwise a set of their UriRefs
      */
     public Set<Iri> getNamedGraphs();

http://git-wip-us.apache.org/repos/asf/clerezza/blob/9ae0a1bc/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/GraphGraphPattern.java
----------------------------------------------------------------------
diff --git a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/GraphGraphPattern.java b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/GraphGraphPattern.java
index 56f861d..0a4844d 100644
--- a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/GraphGraphPattern.java
+++ b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/GraphGraphPattern.java
@@ -19,7 +19,7 @@
 package org.apache.clerezza.rdf.core.sparql.query;
 
 /**
- * Defines a graph graph pattern.
+ * Defines a ImmutableGraph ImmutableGraph pattern.
  * @see <a href="http://www.w3.org/TR/rdf-sparql-query/#queryDataset">
  * SPARQL Query Language: 8.3 Querying the Dataset</a>
  *
@@ -29,7 +29,7 @@ public interface GraphGraphPattern extends GraphPattern {
 
     /**
      *
-     * @return a {@link UriRefOrVariable} which specifies the graph
+     * @return a {@link UriRefOrVariable} which specifies the ImmutableGraph
      *        against which the pattern should match.
      */
     public UriRefOrVariable getGraph();

http://git-wip-us.apache.org/repos/asf/clerezza/blob/9ae0a1bc/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/GraphPattern.java
----------------------------------------------------------------------
diff --git a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/GraphPattern.java b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/GraphPattern.java
index 1d59830..eca02f2 100644
--- a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/GraphPattern.java
+++ b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/GraphPattern.java
@@ -19,7 +19,7 @@
 package org.apache.clerezza.rdf.core.sparql.query;
 
 /**
- * This is the generic interface for all types of graph patterns:
+ * This is the generic interface for all types of ImmutableGraph patterns:
  * {@link BasicGraphPattern}, {@link PathSupportedBasicGraphPattern}, {@link GroupGraphPattern},
  * {@link GraphGraphPattern}, {@link AlternativeGraphPattern}, and
  * {@link OptionalGraphPattern}

http://git-wip-us.apache.org/repos/asf/clerezza/blob/9ae0a1bc/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/GroupGraphPattern.java
----------------------------------------------------------------------
diff --git a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/GroupGraphPattern.java b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/GroupGraphPattern.java
index 03ee08e..95990a9 100644
--- a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/GroupGraphPattern.java
+++ b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/GroupGraphPattern.java
@@ -23,9 +23,9 @@ import java.util.Set;
 import org.apache.commons.rdf.Iri;
 
 /**
- * Defines a group graph pattern.
+ * Defines a group ImmutableGraph pattern.
  * @see <a href="http://www.w3.org/TR/rdf-sparql-query/#GroupPatterns">
- * SPARQL Query Language: 5.2 Group Graph Patterns</a>
+ * SPARQL Query Language: 5.2 Group ImmutableGraph Patterns</a>
  *
  * @author hasan
  */
@@ -56,7 +56,7 @@ public interface GroupGraphPattern extends GraphPattern {
     /**
      * 
      * @return
-     *      all graphs referred in this graph pattern.
+     *      all graphs referred in this ImmutableGraph pattern.
      */
     public Set<Iri> getReferredGraphs();
 

http://git-wip-us.apache.org/repos/asf/clerezza/blob/9ae0a1bc/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/MinusGraphPattern.java
----------------------------------------------------------------------
diff --git a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/MinusGraphPattern.java b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/MinusGraphPattern.java
index d383de1..73a27f5 100644
--- a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/MinusGraphPattern.java
+++ b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/MinusGraphPattern.java
@@ -27,14 +27,14 @@ public interface MinusGraphPattern extends GraphPattern {
     /**
      *
      * @return
-     *        the minuend graph pattern to match
+     *        the minuend ImmutableGraph pattern to match
      */
     public GraphPattern getMinuendGraphPattern();
 
     /**
      *
      * @return
-     *        the subtrahend graph pattern to match
+     *        the subtrahend ImmutableGraph pattern to match
      */
     public GroupGraphPattern getSubtrahendGraphPattern();
 }

http://git-wip-us.apache.org/repos/asf/clerezza/blob/9ae0a1bc/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/OptionalGraphPattern.java
----------------------------------------------------------------------
diff --git a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/OptionalGraphPattern.java b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/OptionalGraphPattern.java
index 4190560..0bca8aa 100644
--- a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/OptionalGraphPattern.java
+++ b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/OptionalGraphPattern.java
@@ -19,9 +19,9 @@
 package org.apache.clerezza.rdf.core.sparql.query;
 
 /**
- * Specifying an optional graph pattern implies the existence of a main graph
+ * Specifying an optional ImmutableGraph pattern implies the existence of a main ImmutableGraph
  * pattern.
- * The main graph pattern is an empty group pattern if it is not specified.
+ * The main ImmutableGraph pattern is an empty group pattern if it is not specified.
  * @see <a href="http://www.w3.org/TR/rdf-sparql-query/#optionals">
  * SPARQL Query Language: 6 Including Optional Values</a>
  * 
@@ -32,14 +32,14 @@ public interface OptionalGraphPattern extends GraphPattern {
     /**
      *
      * @return
-     *        the main graph pattern to match
+     *        the main ImmutableGraph pattern to match
      */
     public GraphPattern getMainGraphPattern();
 
     /**
      *
      * @return
-     *        the optional graph pattern to match
+     *        the optional ImmutableGraph pattern to match
      */
     public GroupGraphPattern getOptionalGraphPattern();
 }

http://git-wip-us.apache.org/repos/asf/clerezza/blob/9ae0a1bc/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/PathSupportedBasicGraphPattern.java
----------------------------------------------------------------------
diff --git a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/PathSupportedBasicGraphPattern.java b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/PathSupportedBasicGraphPattern.java
index 60ace91..f71b10d 100644
--- a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/PathSupportedBasicGraphPattern.java
+++ b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/PathSupportedBasicGraphPattern.java
@@ -21,13 +21,13 @@ package org.apache.clerezza.rdf.core.sparql.query;
 import java.util.Set;
 
 /**
- * Defines a basic graph pattern that supports property path expressions.
+ * Defines a basic ImmutableGraph pattern that supports property path expressions.
  * A {@link PathSupportedBasicGraphPattern} is a set of {@link PropertyPathPattern}s.
  * A {@link PropertyPathPattern} is a generalization of a {@link TriplePattern} to include
  * a {@link PropertyPathExpression} in the property position.
  * Therefore, a {@link PathSupportedBasicGraphPattern} can be seen as a generalization of a {@link BasicGraphPattern}
  * @see <a href="http://www.w3.org/TR/2013/REC-sparql11-query-20130321/#sparqlBasicGraphPatterns">
- * SPARQL 1.1 Query Language: 18.1.6 Basic Graph Patterns</a>
+ * SPARQL 1.1 Query Language: 18.1.6 Basic ImmutableGraph Patterns</a>
  * and <a href="http://www.w3.org/TR/2013/REC-sparql11-query-20130321/#sparqlPropertyPaths">
  * SPARQL 1.1 Query Language: 18.1.7 Property Path Patterns</a>
  *

http://git-wip-us.apache.org/repos/asf/clerezza/blob/9ae0a1bc/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/PatternExistenceCondition.java
----------------------------------------------------------------------
diff --git a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/PatternExistenceCondition.java b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/PatternExistenceCondition.java
index 1d0990b..34e66bd 100644
--- a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/PatternExistenceCondition.java
+++ b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/PatternExistenceCondition.java
@@ -22,11 +22,11 @@ import java.util.ArrayList;
 import java.util.List;
 
 /**
- * This expression is intended to be used as a filter expression to test whether a graph pattern matches 
- * the dataset or not, given the values of variables in the group graph pattern in which the filter occurs.
+ * This expression is intended to be used as a filter expression to test whether a ImmutableGraph pattern matches 
+ * the dataset or not, given the values of variables in the group ImmutableGraph pattern in which the filter occurs.
  * It does not generate any additional bindings.
  * 
- * @see <a href="http://www.w3.org/TR/sparql11-query/#neg-pattern">SPARQL 1.1 Query Language: 8.1 Filtering Using Graph Patterns</a>
+ * @see <a href="http://www.w3.org/TR/sparql11-query/#neg-pattern">SPARQL 1.1 Query Language: 8.1 Filtering Using ImmutableGraph Patterns</a>
  * 
  * @author hasan
  */

http://git-wip-us.apache.org/repos/asf/clerezza/blob/9ae0a1bc/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/Query.java
----------------------------------------------------------------------
diff --git a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/Query.java b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/Query.java
index 68c8c92..6f4909d 100644
--- a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/Query.java
+++ b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/Query.java
@@ -29,19 +29,19 @@ public interface Query {
 
     /**
      * <p>Gets {@link DataSet} containing the specification of the default
-     * graph and named graphs, if any.</p>
+     * ImmutableGraph and named graphs, if any.</p>
      * @see <a href="http://www.w3.org/TR/rdf-sparql-query/#specifyingDataset">
      * SPARQL Query Language: 8.2 Specifying RDF Datasets</a>
      * @return
      *        null if no data set is specified, indicating the use of
-     *        system default graph. Otherwise a {@link DataSet} object is returned.
+     *        system default ImmutableGraph. Otherwise a {@link DataSet} object is returned.
      */
     public DataSet getDataSet();
 
     /**
      * <p>Gets the query pattern of the WHERE clause for the query.</p>
      * @see <a href="http://www.w3.org/TR/rdf-sparql-query/#GraphPattern">
-     * SPARQL Query Language: 5 Graph Patterns</a>
+     * SPARQL Query Language: 5 ImmutableGraph Patterns</a>
      * @return
      *        the {@link GroupGraphPattern} of the WHERE clause for this query.
      *        If the WHERE clause is not specified, null is returned.

http://git-wip-us.apache.org/repos/asf/clerezza/blob/9ae0a1bc/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/ServiceGraphPattern.java
----------------------------------------------------------------------
diff --git a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/ServiceGraphPattern.java b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/ServiceGraphPattern.java
index d437743..9ae6f1a 100644
--- a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/ServiceGraphPattern.java
+++ b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/ServiceGraphPattern.java
@@ -19,7 +19,7 @@
 package org.apache.clerezza.rdf.core.sparql.query;
 
 /**
- * Defines a service graph pattern.
+ * Defines a service ImmutableGraph pattern.
  * @see <a href="http://www.w3.org/TR/sparql11-federated-query/">
  * SPARQL 1.1 Federated Query</a>
  *

http://git-wip-us.apache.org/repos/asf/clerezza/blob/9ae0a1bc/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/impl/SimpleGraphGraphPattern.java
----------------------------------------------------------------------
diff --git a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/impl/SimpleGraphGraphPattern.java b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/impl/SimpleGraphGraphPattern.java
index 5cd87b0..45badaa 100644
--- a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/impl/SimpleGraphGraphPattern.java
+++ b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/impl/SimpleGraphGraphPattern.java
@@ -28,24 +28,24 @@ import org.apache.clerezza.rdf.core.sparql.query.UriRefOrVariable;
  */
 public class SimpleGraphGraphPattern implements GraphGraphPattern {
 
-    private UriRefOrVariable graph;
+    private UriRefOrVariable ImmutableGraph;
     private GroupGraphPattern groupGraphPattern;
 
-    public SimpleGraphGraphPattern(UriRefOrVariable graph,
+    public SimpleGraphGraphPattern(UriRefOrVariable ImmutableGraph,
             GroupGraphPattern groupGraphPattern) {
-        if (graph == null) {
-            throw new IllegalArgumentException("Graph may not be null");
+        if (ImmutableGraph == null) {
+            throw new IllegalArgumentException("ImmutableGraph may not be null");
         }
         if (groupGraphPattern == null) {
-            throw new IllegalArgumentException("Group Graph Pattern may not be null");
+            throw new IllegalArgumentException("Group ImmutableGraph Pattern may not be null");
         }
-        this.graph = graph;
+        this.ImmutableGraph = ImmutableGraph;
         this.groupGraphPattern = groupGraphPattern;
     }
 
     @Override
     public UriRefOrVariable getGraph() {
-        return graph;
+        return ImmutableGraph;
     }
 
     @Override

http://git-wip-us.apache.org/repos/asf/clerezza/blob/9ae0a1bc/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/impl/SimpleGroupGraphPattern.java
----------------------------------------------------------------------
diff --git a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/impl/SimpleServiceGraphPattern.java b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/impl/SimpleServiceGraphPattern.java
index ae4a33a..24d6797 100644
--- a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/impl/SimpleServiceGraphPattern.java
+++ b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/impl/SimpleServiceGraphPattern.java
@@ -38,7 +38,7 @@ public class SimpleServiceGraphPattern implements ServiceGraphPattern {
             throw new IllegalArgumentException("Service endpoint may not be null");
         }
         if (groupGraphPattern == null) {
-            throw new IllegalArgumentException("Group Graph Pattern may not be null");
+            throw new IllegalArgumentException("Group ImmutableGraph Pattern may not be null");
         }
         this.service = service;
         this.groupGraphPattern = groupGraphPattern;

http://git-wip-us.apache.org/repos/asf/clerezza/blob/9ae0a1bc/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/impl/SimpleStringQuerySerializer.java
----------------------------------------------------------------------
diff --git a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/impl/SimpleStringQuerySerializer.java b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/impl/SimpleStringQuerySerializer.java
index 9466c1b..4a916c2 100644
--- a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/impl/SimpleStringQuerySerializer.java
+++ b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/impl/SimpleStringQuerySerializer.java
@@ -160,7 +160,7 @@ public class SimpleStringQuerySerializer extends StringQuerySerializer {
                 }
             }
         } else if (graphPattern instanceof GraphGraphPattern) {
-            s.append("GRAPH ");
+            s.append("ImmutableGraph ");
             appendResourceOrVariable(s, ((GraphGraphPattern) graphPattern).getGraph());
             s.append(" ");
             appendGroupGraphPattern(s, ((GraphGraphPattern) graphPattern).getGroupGraphPattern());

http://git-wip-us.apache.org/repos/asf/clerezza/blob/9ae0a1bc/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/update/impl/AddOperation.java
----------------------------------------------------------------------
diff --git a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/update/impl/AddOperation.java b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/update/impl/AddOperation.java
index a3b9700..36344b6 100644
--- a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/update/impl/AddOperation.java
+++ b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/update/impl/AddOperation.java
@@ -19,8 +19,8 @@
 package org.apache.clerezza.rdf.core.sparql.update.impl;
 
 /**
- * The ADD operation is a shortcut for inserting all data from an input graph into a destination graph. 
- * Data from the input graph is not affected, and initial data from the destination graph, if any, is kept intact.
+ * The ADD operation is a shortcut for inserting all data from an input ImmutableGraph into a destination ImmutableGraph. 
+ * Data from the input ImmutableGraph is not affected, and initial data from the destination ImmutableGraph, if any, is kept intact.
  * @see <a href="http://www.w3.org/TR/2013/REC-sparql11-update-20130321/#add">SPARQL 1.1 Update: 3.2.5 ADD</a>
  * 
  * @author hasan

http://git-wip-us.apache.org/repos/asf/clerezza/blob/9ae0a1bc/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/update/impl/BaseUpdateOperation.java
----------------------------------------------------------------------
diff --git a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/update/impl/BaseUpdateOperation.java b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/update/impl/BaseUpdateOperation.java
index 86f4dd8..41ce0ff 100644
--- a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/update/impl/BaseUpdateOperation.java
+++ b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/update/impl/BaseUpdateOperation.java
@@ -64,7 +64,7 @@ public abstract class BaseUpdateOperation implements UpdateOperation {
                 return result;
             case NAMED:
             case ALL:
-                return tcProvider.listTripleCollections();
+                return tcProvider.listGraphs();
             default:
                 return graphs;
         }
@@ -75,11 +75,11 @@ public abstract class BaseUpdateOperation implements UpdateOperation {
         return getGraphs(defaultGraph, tcProvider, destinationGraphSpec, destinationGraphs);
     }
 
-    public void addInputGraph(Iri graph) {
-        inputGraphs.add(graph);
+    public void addInputGraph(Iri ImmutableGraph) {
+        inputGraphs.add(ImmutableGraph);
     }
 
-    public void addDestinationGraph(Iri graph) {
-        destinationGraphs.add(graph);
+    public void addDestinationGraph(Iri ImmutableGraph) {
+        destinationGraphs.add(ImmutableGraph);
     }
 }

http://git-wip-us.apache.org/repos/asf/clerezza/blob/9ae0a1bc/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/update/impl/LoadOperation.java
----------------------------------------------------------------------
diff --git a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/update/impl/LoadOperation.java b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/update/impl/LoadOperation.java
index ec63d09..cb1429e 100644
--- a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/update/impl/LoadOperation.java
+++ b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/update/impl/LoadOperation.java
@@ -23,9 +23,9 @@ import org.apache.commons.rdf.Iri;
 import org.apache.clerezza.rdf.core.sparql.update.UpdateOperation;
 
 /**
- * The LOAD operation reads an RDF document from a IRI and inserts its triples into the specified graph in the Graph Store. 
- * If the destination graph already exists, then no data in that graph will be removed.
- * If no destination graph IRI is provided to load the triples into, then the data will be loaded into the default graph.
+ * The LOAD operation reads an RDF document from a IRI and inserts its triples into the specified ImmutableGraph in the ImmutableGraph Store. 
+ * If the destination ImmutableGraph already exists, then no data in that ImmutableGraph will be removed.
+ * If no destination ImmutableGraph IRI is provided to load the triples into, then the data will be loaded into the default ImmutableGraph.
  * @see <a href="http://www.w3.org/TR/2013/REC-sparql11-update-20130321/#load">SPARQL 1.1 Update: 3.1.4 LOAD</a>
  * @author hasan
  */

http://git-wip-us.apache.org/repos/asf/clerezza/blob/9ae0a1bc/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/update/impl/ModifyOperation.java
----------------------------------------------------------------------
diff --git a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/update/impl/Quad.java b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/update/impl/Quad.java
index 1a64812..ff26de0 100644
--- a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/update/impl/Quad.java
+++ b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/update/impl/Quad.java
@@ -29,14 +29,14 @@ import org.apache.clerezza.rdf.core.sparql.query.impl.SimpleBasicGraphPattern;
  */
 public class Quad extends SimpleBasicGraphPattern {
 
-    private UriRefOrVariable graph = null;
+    private UriRefOrVariable ImmutableGraph = null;
 
-    public Quad(UriRefOrVariable graph, Set<TriplePattern> triplePatterns) {
+    public Quad(UriRefOrVariable ImmutableGraph, Set<TriplePattern> triplePatterns) {
         super(triplePatterns);
-        this.graph = graph;
+        this.ImmutableGraph = ImmutableGraph;
     }
 
     public UriRefOrVariable getGraph() {
-        return this.graph;
+        return this.ImmutableGraph;
     }
 }

http://git-wip-us.apache.org/repos/asf/clerezza/blob/9ae0a1bc/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/update/impl/UpdateOperationWithQuads.java
----------------------------------------------------------------------
diff --git a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/update/impl/UpdateOperationWithQuads.java b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/update/impl/UpdateOperationWithQuads.java
index a36353c..f641d0b 100644
--- a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/update/impl/UpdateOperationWithQuads.java
+++ b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/update/impl/UpdateOperationWithQuads.java
@@ -48,11 +48,11 @@ public class UpdateOperationWithQuads implements UpdateOperation {
         }
     }
 
-    public void addQuad(UriRefOrVariable graph, Set<TriplePattern> triplePatterns) {
-        if (graph == null) {
+    public void addQuad(UriRefOrVariable ImmutableGraph, Set<TriplePattern> triplePatterns) {
+        if (ImmutableGraph == null) {
             addQuad(triplePatterns);
         } else {
-            quads.add(new Quad(graph, triplePatterns));
+            quads.add(new Quad(ImmutableGraph, triplePatterns));
         }
     }
 
@@ -68,9 +68,9 @@ public class UpdateOperationWithQuads implements UpdateOperation {
             graphs.add(defaultGraph);
         }
         for (Quad quad : quads) {
-            UriRefOrVariable graph = quad.getGraph();
-            if (!graph.isVariable()) {
-                graphs.add(graph.getResource());
+            UriRefOrVariable ImmutableGraph = quad.getGraph();
+            if (!ImmutableGraph.isVariable()) {
+                graphs.add(ImmutableGraph.getResource());
             }
         }
         return graphs;

http://git-wip-us.apache.org/repos/asf/clerezza/blob/9ae0a1bc/rdf.core/src/main/resources/META-INF/documentation.nt
----------------------------------------------------------------------
diff --git a/rdf.core/src/main/resources/META-INF/documentation.nt b/rdf.core/src/main/resources/META-INF/documentation.nt
index 8954631..6bbe00e 100644
--- a/rdf.core/src/main/resources/META-INF/documentation.nt
+++ b/rdf.core/src/main/resources/META-INF/documentation.nt
@@ -1,10 +1,10 @@
-<bundle:///smart-content-binding-content-content-el/0-content> <http://discobits.org/ontology#infoBit> "<p xmlns=\"http://www.w3.org/1999/xhtml\">\n\t\t\tSmart Content Binding (SCB) is an open source framework developed by \n\t\t\tclerezza.org aiming primarily at providing a java implementation of the \n\t\t\tgraph data model specified by W3C RDF [<a href=\"#ref1\">1</a>] and \n\t\t\tfunctionalities to operate on that data model. SCB offers a service \n\t\t\tinterface to access multiple named graphs and it can use various \n\t\t\tproviders to manage RDF graphs in a technology specific manner, e.g., \n\t\t\tusing Jena [<a href=\"#ref2\">2</a>] (TBD) or Sesame [<a href=\"#ref3\">3</a>]. \n\t\t\tIt also provides fa\u00E7ades that allow an application to use Jena or Sesame (TBD) \n\t\t\tAPIs to process RDF graphs (note that the choice of a fa\u00E7ade is independent of\n                        the chosen backend; you can for example use the Jena fa\u00E7ade to write\n                   
      your code against the Jena API while using the Sesame provider to store\n                        your data in a Sesame store). \n\t\t\tFurthermore, SCB offers a serialization and a parsing service to convert \n\t\t\ta graph into a certain representation (format) and vice versa. In order \n\t\t\tto support ontologies usage, SCB provides a tool to convert ontologies \n\t\t\tdefined in various formats including RDF/XML into Java classes.\n\t\t</p>\n"^^<http://www.w3.org/1999/02/22-rdf-syntax-ns#XMLLiteral> .
+<bundle:///smart-content-binding-content-content-el/0-content> <http://discobits.org/ontology#infoBit> "<p xmlns=\"http://www.w3.org/1999/xhtml\">\n\t\t\tSmart Content Binding (SCB) is an open source framework developed by \n\t\t\tclerezza.org aiming primarily at providing a java implementation of the \n\t\t\tgraph data model specified by W3C RDF [<a href=\"#ref1\">1</a>] and \n\t\t\tfunctionalities to operate on that data model. SCB offers a service \n\t\t\tinterface to access multiple named graphs and it can use various \n\t\t\tproviders to manage RDF graphs in a technology specific manner, e.g., \n\t\t\tusing Jena [<a href=\"#ref2\">2</a>] (TBD) or Sesame [<a href=\"#ref3\">3</a>]. \n\t\t\tIt also provides fa\u00E7ades that allow an application to use Jena or Sesame (TBD) \n\t\t\tAPIs to process RDF graphs (note that the choice of a fa\u00E7ade is independent of\n                        the chosen backend; you can for example use the Jena fa\u00E7ade to write\n                   
      your code against the Jena API while using the Sesame provider to store\n                        your data in a Sesame store). \n\t\t\tFurthermore, SCB offers a serialization and a parsing service to convert \n\t\t\ta ImmutableGraph into a certain representation (format) and vice versa. In order \n\t\t\tto support ontologies usage, SCB provides a tool to convert ontologies \n\t\t\tdefined in various formats including RDF/XML into Java classes.\n\t\t</p>\n"^^<http://www.w3.org/1999/02/22-rdf-syntax-ns#XMLLiteral> .
 <bundle:///smart-content-binding-content-content-el/0-content> <http://www.w3.org/1999/02/22-rdf-syntax-ns#type> <http://discobits.org/ontology#XHTMLInfoDiscoBit> .
 <bundle:///smart-content-binding-content-content-el/0-title> <http://discobits.org/ontology#infoBit> "Introduction"^^<http://www.w3.org/1999/02/22-rdf-syntax-ns#XMLLiteral> .
 <bundle:///smart-content-binding-content-content-el/0-title> <http://www.w3.org/1999/02/22-rdf-syntax-ns#type> <http://discobits.org/ontology#XHTMLInfoDiscoBit> .
 <bundle:///smart-content-binding-content-content-el/0> <http://discobits.org/ontology#infoBit> "<strong xmlns=\"http://www.w3.org/1999/xhtml\">Introduction</strong>"^^<http://www.w3.org/1999/02/22-rdf-syntax-ns#XMLLiteral> .
 <bundle:///smart-content-binding-content-content-el/0> <http://www.w3.org/1999/02/22-rdf-syntax-ns#type> <http://discobits.org/ontology#XHTMLInfoDiscoBit> .
-<bundle:///smart-content-binding-content-content-el/1-content> <http://discobits.org/ontology#infoBit> "<p xmlns=\"http://www.w3.org/1999/xhtml\">\n\t\t\tSCB comprises the following architectural components as depicted in Fig. 1:\n\t\t</p>\n\t\t<ul xmlns=\"http://www.w3.org/1999/xhtml\">\n\t\t\t<li>Core</li>\n\t\t\t<li>Facades</li>\n\t\t\t<li>Utilities</li>\n\t\t\t<li>Storage Providers</li>\n\t\t\t<li>Parsing Providers</li>\n\t\t\t<li>Serializing Providers</li>\n\t\t\t<li>Ontologies Tool</li>\n\t\t</ul>\n\n\t\t<p xmlns=\"http://www.w3.org/1999/xhtml\">\n\t\t\t<img alt=\"SCB Architecture\" src=\"images/scb_architecture.png\"></img>\n\t\t\t<br></br><i>Figure 1: SCB Architecture</i>\n\t\t</p>\n\t\t<p xmlns=\"http://www.w3.org/1999/xhtml\">\n\t\t\tThe Core contains interface definitions of the RDF graph data model and its \n\t\t\timplementation. The three main classes are <code>Graph</code>, <code>MGraph</code>, \n\t\t\tand <code>TripleCollection</code>. The class <code>Graph</code> rep
 resents an \n\t\t\timmutable RDF Graph, as such its identity criterion is defined in terms of \n\t\t\tgraph-isomorphism. The class <code>MGraph</code> represents a mutable RDF Graph, \n\t\t\twhich enables triples to be added to or removed from a graph. The class \n\t\t\t<code>TripleCollection</code> is the super class of both the class <code>Graph</code> \n\t\t\tand <code>M</code><code></code><code></code><code></code><code></code><code></code><code></code><code></code><code>Graph</code>. \n\t\t\tSCB Core provides three services: <code>TcManager</code> [<a href=\"#ref4\">4</a>] allows access to \n\t\t\tthe various <code>TripleCollection</code>s, <code>Parser</code> [<a href=\"#ref5\">5</a>] and \n\t\t\t<code>Serializer</code> [<a href=\"#ref6\">6</a>] to allow reading and writing graphs from and to \n\t\t\tvarious formats. In an OSGi environment these services are accessed using the \n\t\t\tservice registry or injected using OSGi Declarative Services. In a non OSGi environment \n\t\
 t\tstatic factory methods are used to return an instance. \n\t\t\tThe <code>TcManager</code> delegates actual processing tasks to a specific Storage Provider \n\t\t\tchosen from a set of Storage Providers based on their priority number (weight). \n\t\t\tStorage Providers can be dynamically bound to or unbound from the Core. \n\t\t\tThe functionality required by the Parser and Serializer is delegated to registered \n\t\t\tParsing and Serializing Providers respectively, according to their capability \n\t\t\t(supported formats). Later registered providers shadow previous ones for the same format.\n\t\t</p>\n\n\t\t<p xmlns=\"http://www.w3.org/1999/xhtml\">\n\t\t\tThe current implementation of SCB includes a Jena Fa\u00E7ade. The Jena Fa\u00E7ade allows an \n\t\t\tapplication to use Jena API to manipulate a TC. \n\t\t</p>\n\t\t<p xmlns=\"http://www.w3.org/1999/xhtml\">\n\t\t\tIn order to ease operations on a resource in a TC, the Utilities component provides \n\t\t\ta class with a set of
  useful methods, e.g., to delete all triples (statements) with \n\t\t\tthe resource as subject and a specified predicate. \n\t\t</p>\n\t\t<p xmlns=\"http://www.w3.org/1999/xhtml\">\n\t\t\tFinally, the Ontologies Tool contains a standalone application called SchemaGen to \n\t\t\tgenerate the Java source code with constants from an ontology description.\n\t\t</p>\n"^^<http://www.w3.org/1999/02/22-rdf-syntax-ns#XMLLiteral> .
+<bundle:///smart-content-binding-content-content-el/1-content> <http://discobits.org/ontology#infoBit> "<p xmlns=\"http://www.w3.org/1999/xhtml\">\n\t\t\tSCB comprises the following architectural components as depicted in Fig. 1:\n\t\t</p>\n\t\t<ul xmlns=\"http://www.w3.org/1999/xhtml\">\n\t\t\t<li>Core</li>\n\t\t\t<li>Facades</li>\n\t\t\t<li>Utilities</li>\n\t\t\t<li>Storage Providers</li>\n\t\t\t<li>Parsing Providers</li>\n\t\t\t<li>Serializing Providers</li>\n\t\t\t<li>Ontologies Tool</li>\n\t\t</ul>\n\n\t\t<p xmlns=\"http://www.w3.org/1999/xhtml\">\n\t\t\t<img alt=\"SCB Architecture\" src=\"images/scb_architecture.png\"></img>\n\t\t\t<br></br><i>Figure 1: SCB Architecture</i>\n\t\t</p>\n\t\t<p xmlns=\"http://www.w3.org/1999/xhtml\">\n\t\t\tThe Core contains interface definitions of the RDF ImmutableGraph data model and its \n\t\t\timplementation. The three main classes are <code>ImmutableGraph</code>, <code>Graph</code>, \n\t\t\tand <code>Graph</code>. The class <code>ImmutableG
 raph</code> represents an \n\t\t\timmutable RDF ImmutableGraph, as such its identity criterion is defined in terms of \n\t\t\tgraph-isomorphism. The class <code>Graph</code> represents a mutable RDF ImmutableGraph, \n\t\t\twhich enables triples to be added to or removed from a ImmutableGraph. The class \n\t\t\t<code>Graph</code> is the super class of both the class <code>ImmutableGraph</code> \n\t\t\tand <code>M</code><code></code><code></code><code></code><code></code><code></code><code></code><code></code><code>ImmutableGraph</code>. \n\t\t\tSCB Core provides three services: <code>TcManager</code> [<a href=\"#ref4\">4</a>] allows access to \n\t\t\tthe various <code>Graph</code>s, <code>Parser</code> [<a href=\"#ref5\">5</a>] and \n\t\t\t<code>Serializer</code> [<a href=\"#ref6\">6</a>] to allow reading and writing graphs from and to \n\t\t\tvarious formats. In an OSGi environment these services are accessed using the \n\t\t\tservice registry or injected using OSGi Declarative Serv
 ices. In a non OSGi environment \n\t\t\tstatic factory methods are used to return an instance. \n\t\t\tThe <code>TcManager</code> delegates actual processing tasks to a specific Storage Provider \n\t\t\tchosen from a set of Storage Providers based on their priority number (weight). \n\t\t\tStorage Providers can be dynamically bound to or unbound from the Core. \n\t\t\tThe functionality required by the Parser and Serializer is delegated to registered \n\t\t\tParsing and Serializing Providers respectively, according to their capability \n\t\t\t(supported formats). Later registered providers shadow previous ones for the same format.\n\t\t</p>\n\n\t\t<p xmlns=\"http://www.w3.org/1999/xhtml\">\n\t\t\tThe current implementation of SCB includes a Jena Fa\u00E7ade. The Jena Fa\u00E7ade allows an \n\t\t\tapplication to use Jena API to manipulate a TC. \n\t\t</p>\n\t\t<p xmlns=\"http://www.w3.org/1999/xhtml\">\n\t\t\tIn order to ease operations on a resource in a TC, the Utilities component p
 rovides \n\t\t\ta class with a set of useful methods, e.g., to delete all triples (statements) with \n\t\t\tthe resource as subject and a specified predicate. \n\t\t</p>\n\t\t<p xmlns=\"http://www.w3.org/1999/xhtml\">\n\t\t\tFinally, the Ontologies Tool contains a standalone application called SchemaGen to \n\t\t\tgenerate the Java source code with constants from an ontology description.\n\t\t</p>\n"^^<http://www.w3.org/1999/02/22-rdf-syntax-ns#XMLLiteral> .
 <bundle:///smart-content-binding-content-content-el/1-content> <http://www.w3.org/1999/02/22-rdf-syntax-ns#type> <http://discobits.org/ontology#XHTMLInfoDiscoBit> .
 <bundle:///smart-content-binding-content-content-el/1-title> <http://discobits.org/ontology#infoBit> "Architecture"^^<http://www.w3.org/1999/02/22-rdf-syntax-ns#XMLLiteral> .
 <bundle:///smart-content-binding-content-content-el/1-title> <http://www.w3.org/1999/02/22-rdf-syntax-ns#type> <http://discobits.org/ontology#XHTMLInfoDiscoBit> .
@@ -40,7 +40,7 @@
 <bundle:///smart-content-binding-content-content-el/6> <http://discobits.org/ontology#contains> _:a19b1dc6a786e1f624246fa77f26064b1 . 
 <bundle:///smart-content-binding-content-content-el/6> <http://discobits.org/ontology#contains> _:c114892cb40ca25cb7973c1a33bb5efa1 . 
 <bundle:///smart-content-binding-content-content-el/6> <http://www.w3.org/1999/02/22-rdf-syntax-ns#type> <http://discobits.org/ontology#TitledContent> .
-<bundle:///smart-content-binding-content-content-el/7-content> <http://discobits.org/ontology#infoBit> "<p xmlns=\"http://www.w3.org/1999/xhtml\">\n\t\t\tSmart Content Binding (SCB) is an open source framework developed by \n\t\t\tclerezza.org aiming primarily at providing a java implementation of the \n\t\t\tgraph data model specified by W3C RDF  and \n\t\t\tfunctionalities to operate on that data model. SCB offers a service \n\t\t\tinterface to access multiple named graphs and it can use various \n\t\t\tproviders to manage RDF graphs in a technology specific manner, e.g., \n\t\t\tusing Jena <a href=\"#ref2\"> </a> (TBD) or Sesame<a href=\"#ref3\"> </a>. \n\t\t\tIt also provides fa\u00E7ades that allow an application to use Jena or Sesame (TBD) \n\t\t\tAPIs to process RDF graphs (note that the choice of a fa\u00E7ade is independent of\n                        the chosen backend; you can for example use the Jena fa\u00E7ade to write\n                        your code against the Jen
 a API while using the Sesame provider to store\n                        your data in a Sesame store). \n\t\t\tFurthermore, SCB offers a serialization and a parsing service to convert \n\t\t\ta graph into a certain representation (format) and vice versa. In order \n\t\t\tto support ontologies usage, SCB provides a tool to convert ontologies \n\t\t\tdefined in various formats including RDF/XML into Java classes.\n\t\t</p>\n"^^<http://www.w3.org/1999/02/22-rdf-syntax-ns#XMLLiteral> .
+<bundle:///smart-content-binding-content-content-el/7-content> <http://discobits.org/ontology#infoBit> "<p xmlns=\"http://www.w3.org/1999/xhtml\">\n\t\t\tSmart Content Binding (SCB) is an open source framework developed by \n\t\t\tclerezza.org aiming primarily at providing a java implementation of the \n\t\t\tgraph data model specified by W3C RDF  and \n\t\t\tfunctionalities to operate on that data model. SCB offers a service \n\t\t\tinterface to access multiple named graphs and it can use various \n\t\t\tproviders to manage RDF graphs in a technology specific manner, e.g., \n\t\t\tusing Jena <a href=\"#ref2\"> </a> (TBD) or Sesame<a href=\"#ref3\"> </a>. \n\t\t\tIt also provides fa\u00E7ades that allow an application to use Jena or Sesame (TBD) \n\t\t\tAPIs to process RDF graphs (note that the choice of a fa\u00E7ade is independent of\n                        the chosen backend; you can for example use the Jena fa\u00E7ade to write\n                        your code against the Jen
 a API while using the Sesame provider to store\n                        your data in a Sesame store). \n\t\t\tFurthermore, SCB offers a serialization and a parsing service to convert \n\t\t\ta ImmutableGraph into a certain representation (format) and vice versa. In order \n\t\t\tto support ontologies usage, SCB provides a tool to convert ontologies \n\t\t\tdefined in various formats including RDF/XML into Java classes.\n\t\t</p>\n"^^<http://www.w3.org/1999/02/22-rdf-syntax-ns#XMLLiteral> .
 <bundle:///smart-content-binding-content-content-el/7-content> <http://www.w3.org/1999/02/22-rdf-syntax-ns#type> <http://discobits.org/ontology#XHTMLInfoDiscoBit> .
 <bundle:///smart-content-binding-content-content-el/7-title> <http://discobits.org/ontology#infoBit> "Introduction"^^<http://www.w3.org/1999/02/22-rdf-syntax-ns#XMLLiteral> .
 <bundle:///smart-content-binding-content-content-el/7-title> <http://www.w3.org/1999/02/22-rdf-syntax-ns#type> <http://discobits.org/ontology#XHTMLInfoDiscoBit> .
@@ -64,9 +64,9 @@
 <bundle:///smart-content-binding-content-el/0> <http://www.w3.org/1999/02/22-rdf-syntax-ns#type> <http://discobits.org/ontology#XHTMLInfoDiscoBit> .
 <bundle:///smart-content-binding-content-el/2-content-el/0> <http://discobits.org/ontology#infoBit> "Once you have an overview over SCB the best resource is the javadoc API documentation. The following gives hints and describes best prectices on particular toopics."^^<http://www.w3.org/1999/02/22-rdf-syntax-ns#XMLLiteral> .
 <bundle:///smart-content-binding-content-el/2-content-el/0> <http://www.w3.org/1999/02/22-rdf-syntax-ns#type> <http://discobits.org/ontology#XHTMLInfoDiscoBit> .
-<bundle:///smart-content-binding-content-el/2-content-el/1-content-el/0> <http://discobits.org/ontology#infoBit> "The MGraphs returned by the TcManager are lockable. A LockableMGraph has a getLock()-Method returning a ReadWriteLock. Write-Locks can be used if the applications logic requires it, i.e. when it wants to ensure that the MGraph isn't modified by another thread while some triples are being added or removed bading on the presence or absence of other triples (note that its a violation of the open world assumption if the absence of some triples causes some actions to be done)."^^<http://www.w3.org/1999/02/22-rdf-syntax-ns#XMLLiteral> .
+<bundle:///smart-content-binding-content-el/2-content-el/1-content-el/0> <http://discobits.org/ontology#infoBit> "The MGraphs returned by the TcManager are lockable. A LockableMGraph has a getLock()-Method returning a ReadWriteLock. Write-Locks can be used if the applications logic requires it, i.e. when it wants to ensure that the Graph isn't modified by another thread while some triples are being added or removed bading on the presence or absence of other triples (note that its a violation of the open world assumption if the absence of some triples causes some actions to be done)."^^<http://www.w3.org/1999/02/22-rdf-syntax-ns#XMLLiteral> .
 <bundle:///smart-content-binding-content-el/2-content-el/1-content-el/0> <http://www.w3.org/1999/02/22-rdf-syntax-ns#type> <http://discobits.org/ontology#XHTMLInfoDiscoBit> .
-<bundle:///smart-content-binding-content-el/2-content-el/1-content-el/1> <http://discobits.org/ontology#infoBit> "Readlocks must be used when multiple threads access an MGraph and a method returning an Iterator is used. In this case a read-lock must be obtained before calling the method on MGraph and released only after the last usage of the returned iterator. Failing to do so may result in ConcurrentModification when another threads modifies the MGraph while we are iterating over it."^^<http://www.w3.org/1999/02/22-rdf-syntax-ns#XMLLiteral> .
+<bundle:///smart-content-binding-content-el/2-content-el/1-content-el/1> <http://discobits.org/ontology#infoBit> "Readlocks must be used when multiple threads access an Graph and a method returning an Iterator is used. In this case a read-lock must be obtained before calling the method on Graph and released only after the last usage of the returned iterator. Failing to do so may result in ConcurrentModification when another threads modifies the Graph while we are iterating over it."^^<http://www.w3.org/1999/02/22-rdf-syntax-ns#XMLLiteral> .
 <bundle:///smart-content-binding-content-el/2-content-el/1-content-el/1> <http://www.w3.org/1999/02/22-rdf-syntax-ns#type> <http://discobits.org/ontology#XHTMLInfoDiscoBit> .
 <bundle:///smart-content-binding-content-el/2-content-el/1-content-el/2> <http://discobits.org/ontology#infoBit> "Currently (this might change infuture versions), it is also necessary to lock on the MGraphs against which a sparql select queries is directed. The lock on the MGraphs should be kept till iteration over the resultset is compleeted."^^<http://www.w3.org/1999/02/22-rdf-syntax-ns#XMLLiteral> .
 <bundle:///smart-content-binding-content-el/2-content-el/1-content-el/2> <http://www.w3.org/1999/02/22-rdf-syntax-ns#type> <http://discobits.org/ontology#XHTMLInfoDiscoBit> .
@@ -78,9 +78,9 @@
 <bundle:///smart-content-binding-content-el/2-content-el/1-content-el/3> <http://discobits.org/ontology#contains> _:8ab36b67bdc95792f2115eecc5162cd01 . 
 <bundle:///smart-content-binding-content-el/2-content-el/1-content-el/3> <http://discobits.org/ontology#contains> _:cb3233d321cd250df6fe98812441b5051 . 
 <bundle:///smart-content-binding-content-el/2-content-el/1-content-el/3> <http://www.w3.org/1999/02/22-rdf-syntax-ns#type> <http://discobits.org/ontology#TitledContent> .
-<bundle:///smart-content-binding-content-el/2-content-el/1-content-el/4-content> <http://discobits.org/ontology#infoBit> "The service documentation should be clear about which MGarphs the service might be writing to, so the caller can make sure it holds no read-lock on one of these MGraph."^^<http://www.w3.org/1999/02/22-rdf-syntax-ns#XMLLiteral> .
+<bundle:///smart-content-binding-content-el/2-content-el/1-content-el/4-content> <http://discobits.org/ontology#infoBit> "The service documentation should be clear about which MGarphs the service might be writing to, so the caller can make sure it holds no read-lock on one of these Graph."^^<http://www.w3.org/1999/02/22-rdf-syntax-ns#XMLLiteral> .
 <bundle:///smart-content-binding-content-el/2-content-el/1-content-el/4-content> <http://www.w3.org/1999/02/22-rdf-syntax-ns#type> <http://discobits.org/ontology#XHTMLInfoDiscoBit> .
-<bundle:///smart-content-binding-content-el/2-content-el/1-content-el/4-title> <http://discobits.org/ontology#infoBit> "What is the best way to Lock a Graph in a service? (the developers, wich use the service know nothing about the lock and set own locks - so the service needs to check something) "^^<http://www.w3.org/1999/02/22-rdf-syntax-ns#XMLLiteral> .
+<bundle:///smart-content-binding-content-el/2-content-el/1-content-el/4-title> <http://discobits.org/ontology#infoBit> "What is the best way to Lock a ImmutableGraph in a service? (the developers, wich use the service know nothing about the lock and set own locks - so the service needs to check something) "^^<http://www.w3.org/1999/02/22-rdf-syntax-ns#XMLLiteral> .
 <bundle:///smart-content-binding-content-el/2-content-el/1-content-el/4-title> <http://www.w3.org/1999/02/22-rdf-syntax-ns#type> <http://discobits.org/ontology#XHTMLInfoDiscoBit> .
 <bundle:///smart-content-binding-content-el/2-content-el/1-content-el/4> <http://discobits.org/ontology#contains> _:02b191249bf7687b1462297ecaa885c81 . 
 <bundle:///smart-content-binding-content-el/2-content-el/1-content-el/4> <http://discobits.org/ontology#contains> _:c46179c34632150d8e547e0bfa876b0f1 . 

http://git-wip-us.apache.org/repos/asf/clerezza/blob/9ae0a1bc/rdf.core/src/site/resources/documentation/scb-triaxrs-tutorial/src/main/java/org/example/apache/clerezza/combined/tutorial/TutorialApp.java
----------------------------------------------------------------------
diff --git a/rdf.core/src/site/xsite/content/overview.xhtml b/rdf.core/src/site/xsite/content/overview.xhtml
index d5248e0..74da552 100644
--- a/rdf.core/src/site/xsite/content/overview.xhtml
+++ b/rdf.core/src/site/xsite/content/overview.xhtml
@@ -33,7 +33,7 @@
 		<p>
 			Smart Content Binding (SCB) is an open source framework developed by
 			clerezza.org aiming primarily at providing a java implementation of the
-			graph data model specified by W3C RDF [<a href="#ref1">1</a>] and
+			ImmutableGraph data model specified by W3C RDF [<a href="#ref1">1</a>] and
 			functionalities to operate on that data model. SCB offers a service
 			interface to access multiple named graphs and it can use various
 			providers to manage RDF graphs in a technology specific manner, e.g.,
@@ -44,7 +44,7 @@
                         your code against the Jena API while using the Sesame provider to store
                         your data in a Sesame store).
 			Furthermore, SCB offers a serialization and a parsing service to convert
-			a graph into a certain representation (format) and vice versa. In order
+			a ImmutableGraph into a certain representation (format) and vice versa. In order
 			to support ontologies usage, SCB provides a tool to convert ontologies
 			defined in various formats including RDF/XML into Java classes.
 		</p>
@@ -67,16 +67,16 @@
 			<br/><i>Figure 1: SCB Architecture</i>
 		</p>
 		<p>
-			The Core contains interface definitions of the RDF graph data model and its
-			implementation. The three main classes are <code>Graph</code>, <code>MGraph</code>,
-			and <code>TripleCollection</code>. The class <code>Graph</code> represents an
-			immutable RDF Graph, as such its identity criterion is defined in terms of
-			graph-isomorphism. The class <code>MGraph</code> represents a mutable RDF Graph,
-			which enables triples to be added to or removed from a graph. The class
-			<code>TripleCollection</code> is the super class of both the class <code>Graph</code>
-			and <code>MGraph</code>.
+			The Core contains interface definitions of the RDF ImmutableGraph data model and its
+			implementation. The three main classes are <code>ImmutableGraph</code>, <code>Graph</code>,
+			and <code>Graph</code>. The class <code>ImmutableGraph</code> represents an
+			immutable RDF ImmutableGraph, as such its identity criterion is defined in terms of
+			ImmutableGraph-isomorphism. The class <code>Graph</code> represents a mutable RDF ImmutableGraph,
+			which enables triples to be added to or removed from a ImmutableGraph. The class
+			<code>Graph</code> is the super class of both the class <code>ImmutableGraph</code>
+			and <code>Graph</code>.
 			SCB Core provides three services: <code>TcManager</code> [<a href="#ref4">4</a>] allows access to
-			the various <code>TripleCollection</code>s, <code>Parser</code> [<a href="#ref5">5</a>] and
+			the various <code>Graph</code>s, <code>Parser</code> [<a href="#ref5">5</a>] and
 			<code>Serializer</code> [<a href="#ref6">6</a>] to allow reading and writing graphs from and to
 			various formats. In an OSGi environment these services are accessed using the
 			service registry or injected using OSGi Declarative Services. In a non OSGi environment
diff --git a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/serializedform/Parser.java b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/serializedform/Parser.java
index 9466af6..d7ef8a8 100644
--- a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/serializedform/Parser.java
+++ b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/serializedform/Parser.java
@@ -32,8 +32,8 @@ import java.util.ServiceLoader;
 import java.util.Set;
 import java.util.logging.Level;
 
+import org.apache.commons.rdf.ImmutableGraph;
 import org.apache.commons.rdf.Graph;
-import org.apache.commons.rdf.MGraph;
 import org.apache.commons.rdf.Iri;
 import org.apache.clerezza.rdf.core.impl.SimpleMGraph;
 import org.osgi.service.cm.ConfigurationAdmin;
@@ -51,7 +51,7 @@ import org.slf4j.LoggerFactory;
 
 /**
  * This singleton class provides a method
  * <code>parse</code> to transform serialized RDF forms into {@link Graph}s.
  *
  * Functionality is delegated to registered {@link ParsingProvider}s. Such
  * <code>ParsingProvider</code>s can be registered and unregistered, later
@@ -162,39 +162,39 @@ public class Parser {
     }
 
     /**
      * Parses a serialized Graph from an InputStream. This delegates the
      * processing to the provider registered for the specified format, if
      * the formatIdentifier contains a ';'-character only the section before
      * that character is used for choosing the provider.
      *
      * @param serializedGraph an inputstream with the serialization
      * @param formatIdentifier a string identifying the format (usually the MIME-type)
      * @return the graph read from the stream
      * @throws UnsupportedFormatException
      */
-    public Graph parse(InputStream serializedGraph,
+    public ImmutableGraph parse(InputStream serializedGraph,
             String formatIdentifier) throws UnsupportedFormatException {
         return parse(serializedGraph, formatIdentifier, null);
     }
 
     /**
      * Parses a serialized Graph from an InputStream. This delegates the
      * processing to the provider registered for the specified format, if
      * the formatIdentifier contains a ';'-character only the section before
      * that character is used for choosing the provider.
      *
-     * @param target the MGraph to which the parsed triples are added
+     * @param target the Graph to which the parsed triples are added
      * @param serializedGraph an inputstream with the serialization
      * @param formatIdentifier a string identifying the format (usually the MIME-type)
      * @throws UnsupportedFormatException
      */
-    public void parse(MGraph target, InputStream serializedGraph,
+    public void parse(Graph target, InputStream serializedGraph,
             String formatIdentifier) throws UnsupportedFormatException {
         parse(target, serializedGraph, formatIdentifier, null);
     }
 
     /**
      * Parses a serialized Graph from an InputStream. This delegates the
      * processing to the provider registered for the specified format, if
      * the formatIdentifier contains a ';'-character only the section before
      * that character is used for choosing the provider.
@@ -202,29 +202,29 @@ public class Parser {
      * @param serializedGraph an inputstream with the serialization
      * @param formatIdentifier a string identifying the format (usually the MIME-type)
      * @param baseUri the uri against which relative uri-refs are evaluated
      * @return the graph read from the stream
      * @throws UnsupportedFormatException
      */
-    public Graph parse(InputStream serializedGraph,
+    public ImmutableGraph parse(InputStream serializedGraph,
             String formatIdentifier, Iri baseUri) throws UnsupportedFormatException {
-        MGraph mGraph = new SimpleMGraph();
-        parse(mGraph, serializedGraph, formatIdentifier, baseUri);
-        return mGraph.getGraph();
+        Graph graph = new SimpleMGraph();
+        parse(graph, serializedGraph, formatIdentifier, baseUri);
+        return graph.getImmutableGraph();
     }
 
     /**
      * Parses a serialized Graph from an InputStream. This delegates the
      * processing to the provider registered for the specified format, if
      * the formatIdentifier contains a ';'-character only the section before
      * that character is used for choosing the provider.
      *
-     * @param target the MGraph to which the parsed triples are added
+     * @param target the Graph to which the parsed triples are added
      * @param serializedGraph an inputstream with the serialization
      * @param formatIdentifier a string identifying the format (usually the MIME-type)
      * @param baseUri the uri against which relative uri-refs are evaluated
      * @throws UnsupportedFormatException
      */
-    public void parse(MGraph target, InputStream serializedGraph,
+    public void parse(Graph target, InputStream serializedGraph,
             String formatIdentifier, Iri baseUri) throws UnsupportedFormatException {
         String deParameterizedIdentifier;
         int semicolonPos = formatIdentifier.indexOf(';');

http://git-wip-us.apache.org/repos/asf/clerezza/blob/9ae0a1bc/rdf.core/src/main/java/org/apache/clerezza/rdf/core/serializedform/ParsingProvider.java
----------------------------------------------------------------------
@@ -51,7 +51,7 @@ import org.slf4j.LoggerFactory;
 /**
  * This singleton class provides a method
- * <code>parse</code> to transform serialized RDF forms into {@link Graph}s.
+ * <code>parse</code> to transform serialized RDF forms into {@link ImmutableGraph}s.
  *
  * Functionality is delegated to registered {@link ParsingProvider}s. Such
@@ -162,39 +162,39 @@ public class Parser {
 
     /**
-     * Parses a serialized Graph from an InputStream. This delegates the
+     * Parses a serialized ImmutableGraph from an InputStream. This delegates the
      * processing to the provider registered for the specified format, if
      * the formatIdentifier contains a ';'-character only the section before
@@ -162,39 +162,39 @@ public class Parser {
      * @param serializedGraph an inputstream with the serialization
      * @param formatIdentifier a string identifying the format (usually the MIME-type)
-     * @return the graph read from the stream
+     * @return the ImmutableGraph read from the stream
      * @throws UnsupportedFormatException
      */
@@ -162,39 +162,39 @@ public class Parser {
 
     /**
-     * Parses a serialized Graph from an InputStream. This delegates the
+     * Parses a serialized ImmutableGraph from an InputStream. This delegates the
      * processing to the provider registered for the specified format, if
      * the formatIdentifier contains a ';'-character only the section before
@@ -162,39 +162,39 @@ public class Parser {
 
     /**
-     * Parses a serialized Graph from an InputStream. This delegates the
+     * Parses a serialized ImmutableGraph from an InputStream. This delegates the
      * processing to the provider registered for the specified format, if
      * the formatIdentifier contains a ';'-character only the section before
@@ -202,29 +202,29 @@ public class Parser {
      * @param formatIdentifier a string identifying the format (usually the MIME-type)
      * @param baseUri the uri against which relative uri-refs are evaluated
-     * @return the graph read from the stream
+     * @return the ImmutableGraph read from the stream
      * @throws UnsupportedFormatException
      */
@@ -202,29 +202,29 @@ public class Parser {
 
     /**
-     * Parses a serialized Graph from an InputStream. This delegates the
+     * Parses a serialized ImmutableGraph from an InputStream. This delegates the
      * processing to the provider registered for the specified format, if
      * the formatIdentifier contains a ';'-character only the section before
diff --git a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/serializedform/SerializingProvider.java b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/serializedform/SerializingProvider.java
index da65d56..2f49216 100644
--- a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/serializedform/SerializingProvider.java
+++ b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/serializedform/SerializingProvider.java
@@ -20,11 +20,11 @@ package org.apache.clerezza.rdf.core.serializedform;
 
 import java.io.OutputStream;
 
-import org.apache.commons.rdf.TripleCollection;
+import org.apache.commons.rdf.Graph;
 
 
 /**
  * An instance of this class serializes <code>TripleCollection</code>s to a
  * specified serialization format. The supported formats are indicated using the
  * {@link SupportedFormat} annotation.
  *
@@ -32,7 +32,7 @@ import org.apache.commons.rdf.TripleCollection;
  */
 public interface SerializingProvider {
     
     /** Serializes a <code>TripleCollection</code> to a specified
      * <code>OutputStream</code> in the format identified by
      * <code>formatIdentifier</code>. This method will be invoked
      * for a supported format, a format is considered as supported if the part
@@ -43,7 +43,7 @@ public interface SerializingProvider {
      * @param tc
      * @param formatIdentifier
      */
-    public void serialize(OutputStream outputStream, TripleCollection tc,
+    public void serialize(OutputStream outputStream, Graph tc,
             String formatIdentifier);
 
 }

http://git-wip-us.apache.org/repos/asf/clerezza/blob/9ae0a1bc/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/QueryEngine.java
----------------------------------------------------------------------
@@ -20,11 +20,11 @@ package org.apache.clerezza.rdf.core.serializedform;
 
 /**
- * An instance of this class serializes <code>TripleCollection</code>s to a
+ * An instance of this class serializes <code>Graph</code>s to a
  * specified serialization format. The supported formats are indicated using the
  * {@link SupportedFormat} annotation.
@@ -32,7 +32,7 @@ import org.apache.commons.rdf.TripleCollection;
 public interface SerializingProvider {
     
-    /** Serializes a <code>TripleCollection</code> to a specified
+    /** Serializes a <code>Graph</code> to a specified
      * <code>OutputStream</code> in the format identified by
      * <code>formatIdentifier</code>. This method will be invoked
diff --git a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/impl/SimpleGroupGraphPattern.java b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/impl/SimpleGroupGraphPattern.java
index d0ca54f..5a92b41 100644
--- a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/impl/SimpleGroupGraphPattern.java
+++ b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/impl/SimpleGroupGraphPattern.java
@@ -157,10 +157,10 @@ public class SimpleGroupGraphPattern implements GroupGraphPattern {
 
 	/**
 	 * Adds an {@link OptionalGraphPattern} to the group consisting of
 	 * a main graph pattern and the specified {@link GroupGraphPattern} as
 	 * the optional pattern.
 	 * The main graph pattern is taken from the last added {@link GraphPattern}
 	 * in the group, if it exists. Otherwise, the main graph pattern is null.
 	 *
 	 * @param optional
 	 *		a {@link GroupGraphPattern} as the optional pattern of
@@ -206,9 +206,9 @@ public class SimpleGroupGraphPattern implements GroupGraphPattern {
         Set<Iri> referredGraphs = new HashSet<Iri>();
         if (graphPattern instanceof GraphGraphPattern) {
             GraphGraphPattern graphGraphPattern = (GraphGraphPattern) graphPattern;
-            UriRefOrVariable graph = graphGraphPattern.getGraph();
-            if (!graph.isVariable()) {
-                referredGraphs.add(graph.getResource());
+            UriRefOrVariable ImmutableGraph = graphGraphPattern.getGraph();
+            if (!ImmutableGraph.isVariable()) {
+                referredGraphs.add(ImmutableGraph.getResource());
             }
             referredGraphs.addAll(graphGraphPattern.getGroupGraphPattern().getReferredGraphs());
         } else if (graphPattern instanceof AlternativeGraphPattern) {

http://git-wip-us.apache.org/repos/asf/clerezza/blob/9ae0a1bc/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/impl/SimpleMinusGraphPattern.java
----------------------------------------------------------------------
@@ -157,10 +157,10 @@ public class SimpleGroupGraphPattern implements GroupGraphPattern {
 	/**
 	 * Adds an {@link OptionalGraphPattern} to the group consisting of
-	 * a main graph pattern and the specified {@link GroupGraphPattern} as
+	 * a main ImmutableGraph pattern and the specified {@link GroupGraphPattern} as
 	 * the optional pattern.
@@ -157,10 +157,10 @@ public class SimpleGroupGraphPattern implements GroupGraphPattern {
 	 * the optional pattern.
-	 * The main graph pattern is taken from the last added {@link GraphPattern}
-	 * in the group, if it exists. Otherwise, the main graph pattern is null.
+	 * The main ImmutableGraph pattern is taken from the last added {@link GraphPattern}
+	 * in the group, if it exists. Otherwise, the main ImmutableGraph pattern is null.
 	 *
 	 * @param optional
diff --git a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/impl/SimpleMinusGraphPattern.java b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/impl/SimpleMinusGraphPattern.java
index 8a33956..951b9ec 100644
--- a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/impl/SimpleMinusGraphPattern.java
+++ b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/impl/SimpleMinusGraphPattern.java
@@ -34,7 +34,7 @@ public class SimpleMinusGraphPattern implements MinusGraphPattern {
 
     /**
      * Constructs a {@link MinusGraphPattern} out of a {@link GraphPattern}
      * as the minuend graph pattern and a {@link GroupGraphPattern} as the 
      * subtrahend pattern.
      * 
      * @param minuendGraphPattern
@@ -44,7 +44,7 @@ public class SimpleMinusGraphPattern implements MinusGraphPattern {
      */
     public SimpleMinusGraphPattern(GraphPattern minuendGraphPattern, GroupGraphPattern subtrahendGraphPattern) {
         if (subtrahendGraphPattern == null) {
-            throw new IllegalArgumentException("Subtrahend graph pattern may not be null");
+            throw new IllegalArgumentException("Subtrahend ImmutableGraph pattern may not be null");
         }
         if (minuendGraphPattern == null) {
             this.minuendGraphPattern = new SimpleGroupGraphPattern();

http://git-wip-us.apache.org/repos/asf/clerezza/blob/9ae0a1bc/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/impl/SimpleOptionalGraphPattern.java
----------------------------------------------------------------------
@@ -34,7 +34,7 @@ public class SimpleMinusGraphPattern implements MinusGraphPattern {
     /**
      * Constructs a {@link MinusGraphPattern} out of a {@link GraphPattern}
-     * as the minuend graph pattern and a {@link GroupGraphPattern} as the 
+     * as the minuend ImmutableGraph pattern and a {@link GroupGraphPattern} as the 
      * subtrahend pattern.
      * 
diff --git a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/impl/SimpleOptionalGraphPattern.java b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/impl/SimpleOptionalGraphPattern.java
index 137aa08..64abd73 100644
--- a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/impl/SimpleOptionalGraphPattern.java
+++ b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/impl/SimpleOptionalGraphPattern.java
@@ -34,7 +34,7 @@ public class SimpleOptionalGraphPattern implements OptionalGraphPattern {
 
     /**
      * Constructs an {@link OptionalGraphPattern} out of a {@link GraphPattern}
      * as the main graph pattern and a {@link GroupGraphPattern} as the 
      * optional pattern.
      * 
      * @param mainGraphPattern
@@ -45,7 +45,7 @@ public class SimpleOptionalGraphPattern implements OptionalGraphPattern {
     public SimpleOptionalGraphPattern(GraphPattern mainGraphPattern,
             GroupGraphPattern optionalGraphPattern) {
         if (optionalGraphPattern == null) {
-            throw new IllegalArgumentException("Optional graph pattern may not be null");
+            throw new IllegalArgumentException("Optional ImmutableGraph pattern may not be null");
         }
         if (mainGraphPattern == null) {
             this.mainGraphPattern = new SimpleGroupGraphPattern();

http://git-wip-us.apache.org/repos/asf/clerezza/blob/9ae0a1bc/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/query/impl/SimpleServiceGraphPattern.java
----------------------------------------------------------------------
@@ -34,7 +34,7 @@ public class SimpleOptionalGraphPattern implements OptionalGraphPattern {
     /**
      * Constructs an {@link OptionalGraphPattern} out of a {@link GraphPattern}
-     * as the main graph pattern and a {@link GroupGraphPattern} as the 
+     * as the main ImmutableGraph pattern and a {@link GroupGraphPattern} as the 
      * optional pattern.
      * 
diff --git a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/update/impl/ModifyOperation.java b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/update/impl/ModifyOperation.java
index 8c5c0ef..f5b2f6d 100644
--- a/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/update/impl/ModifyOperation.java
+++ b/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/update/impl/ModifyOperation.java
@@ -30,7 +30,7 @@ import org.apache.clerezza.rdf.core.sparql.update.UpdateOperation;
  * This ModifyOperation is a DELETE/INSERT operation.
  * @see <a href="http://www.w3.org/TR/2013/REC-sparql11-update-20130321/#deleteInsert">SPARQL 1.1 Update: 3.1.3 DELETE/INSERT</a>
  * 
  * The DELETE/INSERT operation can be used to remove or add triples from/to the Graph Store based on bindings 
  * for a query pattern specified in a WHERE clause.
  * 
  * @author hasan
@@ -58,11 +58,11 @@ public class ModifyOperation implements UpdateOperation {
         this.dataSet = dataSet;
     }
 
-    public void addGraphToDataSet(Iri graph) {
+    public void addGraphToDataSet(Iri ImmutableGraph) {
         if (dataSet == null) {
             dataSet = new SimpleDataSet();
         }
-        dataSet.addDefaultGraph(graph);
+        dataSet.addDefaultGraph(ImmutableGraph);
     }
 
     public void addNamedGraphToDataSet(Iri namedGraph) {

http://git-wip-us.apache.org/repos/asf/clerezza/blob/9ae0a1bc/rdf.core/src/main/java/org/apache/clerezza/rdf/core/sparql/update/impl/Quad.java
----------------------------------------------------------------------
@@ -30,7 +30,7 @@ import org.apache.clerezza.rdf.core.sparql.update.UpdateOperation;
  * @see <a href="http://www.w3.org/TR/2013/REC-sparql11-update-20130321/#deleteInsert">SPARQL 1.1 Update: 3.1.3 DELETE/INSERT</a>
  * 
- * The DELETE/INSERT operation can be used to remove or add triples from/to the Graph Store based on bindings 
+ * The DELETE/INSERT operation can be used to remove or add triples from/to the ImmutableGraph Store based on bindings 
  * for a query pattern specified in a WHERE clause.
  * 
diff --git a/rdf.core/src/site/resources/documentation/scb-triaxrs-tutorial/src/main/java/org/example/apache/clerezza/combined/tutorial/TutorialApp.java b/rdf.core/src/site/resources/documentation/scb-triaxrs-tutorial/src/main/java/org/example/apache/clerezza/combined/tutorial/TutorialApp.java
index 8965c2c..9a99d5d 100644
--- a/rdf.core/src/site/resources/documentation/scb-triaxrs-tutorial/src/main/java/org/example/apache/clerezza/combined/tutorial/TutorialApp.java
+++ b/rdf.core/src/site/resources/documentation/scb-triaxrs-tutorial/src/main/java/org/example/apache/clerezza/combined/tutorial/TutorialApp.java
@@ -39,11 +39,11 @@ import org.apache.clerezza.platform.typerendering.seedsnipe.SeedsnipeRenderlet;
 import org.apache.clerezza.platform.typerendering.RenderletManager;
 import org.apache.clerezza.rdf.ontologies.FOAF;
 import org.apache.clerezza.rdf.utils.GraphNode;
+import org.apache.clerezza.rdf.core.ImmutableGraph;
 import org.apache.clerezza.rdf.core.Graph;
-import org.apache.clerezza.rdf.core.MGraph;
 import org.apache.clerezza.rdf.core.NonLiteral;
 import org.apache.clerezza.rdf.core.Triple;
-import org.apache.clerezza.rdf.core.TripleCollection;
+import org.apache.clerezza.rdf.core.Graph;
 import org.apache.clerezza.rdf.core.UriRef;
 import org.apache.clerezza.rdf.core.access.NoSuchEntityException;
 import org.apache.clerezza.rdf.core.access.TcManager;
@@ -75,23 +75,23 @@ public class TutorialApp {
     @GET
     @Path("find")
     @Produces("application/rdf+xml")
-    public Graph getPersonRdf(@QueryParam("mbox") String mboxString) {
-        MGraph mGraph = tcManager.getMGraph(graphName);
-        NonLiteral person = getPersonByMbox(mboxString, mGraph);
-        return new GraphNode(person, mGraph).getNodeContext();
+    public ImmutableGraph getPersonRdf(@QueryParam("mbox") String mboxString) {
+        Graph graph = tcManager.getMGraph(graphName);
+        NonLiteral person = getPersonByMbox(mboxString, graph);
+        return new GraphNode(person, graph).getNodeContext();
     }
 
     @GET
     @Path("find")
     @Produces("application/xhtml+xml")
     public GraphNode getPersonHtml(@QueryParam("mbox") String mboxString) {
-        MGraph mGraph = tcManager.getMGraph(graphName);
-        NonLiteral person = getPersonByMbox(mboxString, mGraph);
-        return new GraphNode(person, mGraph);
+        Graph graph = tcManager.getMGraph(graphName);
+        NonLiteral person = getPersonByMbox(mboxString, graph);
+        return new GraphNode(person, graph);
     }
 
-    private NonLiteral getPersonByMbox(String mboxString, MGraph mGraph) {
-        Iterator<Triple> iter = mGraph.filter(null, FOAF.mbox, new UriRef(mboxString));
+    private NonLiteral getPersonByMbox(String mboxString, Graph graph) {
+        Iterator<Triple> iter = graph.filter(null, FOAF.mbox, new UriRef(mboxString));
         NonLiteral person = null;
         while(iter.hasNext()) {
             person = iter.next().getSubject();
@@ -101,7 +101,7 @@ public class TutorialApp {
     
     /**
      * The activate method is called when SCR activates the component configuration.
      * This method gets the system graph or create a new one if it doesn't exist.
      * 
      * @param componentContext
      */
@@ -116,7 +116,7 @@ public class TutorialApp {
         } catch (URISyntaxException ex) {
             throw new WebApplicationException(ex);
         }
-        TripleCollection tc;
+        Graph tc;
         try {
             tcManager.getMGraph(graphName);
         } catch (NoSuchEntityException nsee) {

http://git-wip-us.apache.org/repos/asf/clerezza/blob/9ae0a1bc/rdf.core/src/site/resources/documentation/tutorial1/src/main/java/org/example/apache/clerezza/scb/tutorial1/Tutorial1App.java
----------------------------------------------------------------------
@@ -101,7 +101,7 @@ public class TutorialApp {
     /**
      * The activate method is called when SCR activates the component configuration.
-     * This method gets the system graph or create a new one if it doesn't exist.
+     * This method gets the system ImmutableGraph or create a new one if it doesn't exist.
      * 
      * @param componentContext
diff --git a/rdf.core/src/site/resources/documentation/tutorial1/src/main/java/org/example/apache/clerezza/scb/tutorial1/Tutorial1App.java b/rdf.core/src/site/resources/documentation/tutorial1/src/main/java/org/example/apache/clerezza/scb/tutorial1/Tutorial1App.java
index 41abfff..f0e2e8c 100644
--- a/rdf.core/src/site/resources/documentation/tutorial1/src/main/java/org/example/apache/clerezza/scb/tutorial1/Tutorial1App.java
+++ b/rdf.core/src/site/resources/documentation/tutorial1/src/main/java/org/example/apache/clerezza/scb/tutorial1/Tutorial1App.java
@@ -46,8 +46,8 @@ import javax.swing.JScrollPane;
 import javax.swing.JTable;
 import javax.swing.JTextField;
 import javax.swing.table.AbstractTableModel;
+import org.apache.clerezza.rdf.core.ImmutableGraph;
 import org.apache.clerezza.rdf.core.Graph;
-import org.apache.clerezza.rdf.core.MGraph;
 import org.apache.clerezza.rdf.core.UriRef;
 import org.apache.clerezza.rdf.core.Triple;
 import org.apache.clerezza.rdf.core.access.TcManager;
@@ -64,13 +64,13 @@ import org.apache.clerezza.rdf.utils.GraphNode;
 public class Tutorial1App extends JPanel {
 
     //where our knowledge is stored
-    private MGraph mGraph;
+    private Graph graph;
     //the URI for which the context is shown
     private String selectedUri;
     //These get notified when the selected URI changes
     private Set<UriChangedListener> uriChangedListeners
             = new HashSet<UriChangedListener>();
-    //these get notified when mGraph was modified
+    //these get notified when graph was modified
     private Set<GraphChangedListener> graphChangedListeners
             = new HashSet<GraphChangedListener>();
 
@@ -100,10 +100,10 @@ public class Tutorial1App extends JPanel {
         this.selectedUri = selectedUri;
         //get the singleton instance of TcManager
         final TcManager tcManager = TcManager.getInstance();
         //the arbitrary name we use for our mutable graph
         final UriRef mGraphName = new UriRef("http://tutorial.example.org/");
-        //the m-graph into which we'll put the triples we collect
-        mGraph = tcManager.createMGraph(mGraphName);
+        //the m-ImmutableGraph into which we'll put the triples we collect
+        graph = tcManager.createMGraph(mGraphName);
         try {
             loadContextFromWeb();
         } catch (IOException ex) {
@@ -111,7 +111,7 @@ public class Tutorial1App extends JPanel {
             ex.printStackTrace();
         }
 
-        Iterator<Triple> typeTriples = mGraph.filter(new UriRef(selectedUri), RDF.type, null);
+        Iterator<Triple> typeTriples = graph.filter(new UriRef(selectedUri), RDF.type, null);
         while (typeTriples.hasNext()) {
             System.out.println(typeTriples.next());
         }
@@ -145,12 +145,12 @@ public class Tutorial1App extends JPanel {
      * 
      * @return the context of the currently selected URI
      */
-    public Graph getCurrentContext() {
-        return new GraphNode(new UriRef(selectedUri), mGraph).getNodeContext();
+    public ImmutableGraph getCurrentContext() {
+        return new GraphNode(new UriRef(selectedUri), graph).getNodeContext();
     }
 
     /**
-     * Dereference the selected URI and add the retroieved triples to mGraph
+     * Dereference the selected URI and add the retroieved triples to graph
      *
      * @throws java.io.IOException
      */
@@ -162,9 +162,9 @@ public class Tutorial1App extends JPanel {
 
         //get the singleton instance of Parser
         final Parser parser = Parser.getInstance();
-        Graph deserializedGraph = parser.parse(inputStream, "application/rdf+xml");
+        ImmutableGraph deserializedGraph = parser.parse(inputStream, "application/rdf+xml");
 
-        mGraph.addAll(deserializedGraph);
+        graph.addAll(deserializedGraph);
         for (GraphChangedListener graphChangedListener : graphChangedListeners) {
             graphChangedListener.graphChanged();
         }
@@ -237,16 +237,16 @@ public class Tutorial1App extends JPanel {
 
     private Component createFooter() {
         JPanel footer = new JPanel();
-        footer.add(new JLabel("Size of local graph: "));
-        final JLabel sizeLabel = new JLabel(Integer.toString(mGraph.size()));
+        footer.add(new JLabel("Size of local ImmutableGraph: "));
+        final JLabel sizeLabel = new JLabel(Integer.toString(graph.size()));
         addGraphChangedListeners(new GraphChangedListener() {
 
             @Override
             public void graphChanged() {
-                sizeLabel.setText(Integer.toString(mGraph.size()));
+                sizeLabel.setText(Integer.toString(graph.size()));
             }
         });
-        sizeLabel.setText(Integer.toString(mGraph.size()));
+        sizeLabel.setText(Integer.toString(graph.size()));
         footer.add(sizeLabel);
         return footer;
     }

http://git-wip-us.apache.org/repos/asf/clerezza/blob/9ae0a1bc/rdf.core/src/site/xsite/content/overview.xhtml
----------------------------------------------------------------------
@@ -100,10 +100,10 @@ public class Tutorial1App extends JPanel {
         //get the singleton instance of TcManager
         final TcManager tcManager = TcManager.getInstance();
-        //the arbitrary name we use for our mutable graph
+        //the arbitrary name we use for our mutable ImmutableGraph
         final UriRef mGraphName = new UriRef("http://tutorial.example.org/");